#ifndef FACEREC_POSTION_H
#define FACEREC_POSTION_H 1

class Postion {
	int sx , sy , iWidth , iHeight;
	int offx , offy ;
	float div_factor ;
	int recDx ;
	int recDy ;
	
	// for controls
	int csx,csy;

public:
	
	enum { Train = 0 , Recog = 1, Advanced = 2 , Exit = 3 };

	Postion();
	// RectNo is from 0-3 for the four rectangles
	void GetRectPos ( int & x1 , int & y1 , 
		int & x2 , int & y2 , int RectNo );
	// Get Control's Postion ...
	// 0 - Train
	// 1 - Recog
	// 2 - Advanced
	// 3 - Exit
	void GetCtrPos ( int & x , int & y , int & xSz , int & ysz ,
				int CtrNo );

	// Thumbnail size to fit in Rectangle
	void GetThumbSz ( int & Width , int & Height );
	
	// Offset Postion of Thumbnail in the rectangle
	void GetThumbOffset( int & x , int & y );
	float GetDivFac();
};

extern Postion Pos;

#endif